UNIT uKugel ;
(* ******************************************************************** *)
(* K L A S S E :  TKugel                                                *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.0                                                    *)
(* Autor       : (c) S. Spolwig - OSZ Handel, 10997 Berlin              *)
(* Beschreibung: Das Objekt stellt eine Billardkugel dar.               *)
(*                                                                      *)
(* Compiler    : Delphi 3.0                                             *)
(* Aenderungen : V. 1.0		08-MAY-99                                     *)
(*									1.1   14-JUN-01	 SetLink  													*)
(* ******************************************************************** *)

INTERFACE
(* ==================================================================== *)

USES uGrafik,
     uZeit;

  type
   TKugel = class (TKreis)
             private
              XRichtung,
              YRichtung  : integer;
             public
              procedure SetLink(zbl : TZeichenblatt);
              procedure SetXRichtung (xR : integer);
              procedure SetYRichtung (yR : integer);
              procedure PosVersetzen;

              procedure BandePruefen;
              function  Trifft (andereKugel : TKugel) : boolean;
              procedure RichtungTauschenMit (andereKugel : TKugel);
              procedure Bewegen;
            end;


(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse    : TKreis
Bezugsklassen : TZeichenblatt


Methoden
--------

SetLink (zbl : TZeichenblatt);
  Auftrag: Kugel mit Tisch verbinden, um Bande abzufragen
  vorher : -
  nachher: -

SetXRichtung (xR : integer);
  Auftrag: West-Ost-Richtung festlegen in Pixeln.
  vorher : -
  nachher: -

SetYRichtung (yR : integer);
  Auftrag: Nord-Sued-Richtung festlegen in Pixeln.
  vorher : -
  nachher: -

PosVersetzen
  Auftrag: neue Position festlegen
  vorher :
  nachher: alte Position ist um die Richtungswerte erhoheht

BandePruefen
  Auftrag: Wenn die Bande getroffen wird, den Einfallswinkel
           der Kugel spiegeln.
  vorher :
  nachher: Kugel laueft weiter

Trifft (andereKugel : TKugel) : boolean
   Anfrage: ob eine andere Kugel beruehrt wird
   vorher : andere Kugel ist vorhanden
   nachher: true, wenn der Abstand zwischen beiden Kugel < 25 ist.

RichtungTauschenMit (andereKugel : TKugel)
  Auftrag: wenn eine andere Kugel getroffen ist, tauschen beide ihre
           West-Ost und Nord-Sued Richtungen aus.
  vorher : andere Kugel ist getroffen
  nachher: Kugel Bewegen in entgegengesetzten Richtungen

Bewegen
  Auftrag: Kugel auf dem Bildschirm von alter Position nach neuer Position
           versetzen und zeigen
  vorher : -
  nachher: Kugel ist um den Aenderungswert in x- und yRichtung versetzt.
----------------------------------------------------------------------- *)


IMPLEMENTATION
(* ==================================================================== *)
var Tisch: TZeichenblatt;


procedure TKugel.SetLink (zbl : TZeichenblatt);
(* -------------------------------------------------------------------- *)
begin
  Tisch := zbl;
end;


procedure TKugel.SetXRichtung (xR : integer);
(* -------------------------------------------------------------------- *)
begin
  XRichtung := xR;
end;


procedure TKugel.SetYRichtung (yR : integer);
(* -------------------------------------------------------------------- *)
begin
  YRichtung := yR;
end;

procedure TKugel.PosVersetzen;
(* -------------------------------------------------------------------- *)
begin
  x1 := x1 + xRichtung;
  y1 := y1 + yRichtung;
end;


procedure TKugel.BandePruefen;
(* -------------------------------------------------------------------- *)
begin
  if (GetXPos <= GetRadius) or (GetXPos + GetRadius >= Tisch.GetBreite)
  then XRichtung := - XRichtung;

  if (GetYPos <= GetRadius) or (GetYPos + GetRadius>= Tisch.GetHoehe)
  then YRichtung := - YRichtung;
end;

function  TKugel.Trifft (andereKugel : TKugel) : boolean;
(* -------------------------------------------------------------------- *)
begin
  Result := false;
  if (abs(GetXPos - anderekugel.GetXPos) <= 25) and
     (abs(GetyPos - andereKugel.GetyPos) <= 25)
  then Result := true;
end;


procedure TKugel.RichtungTauschenMit (andereKugel : TKugel);
(* -------------------------------------------------------------------- *)
var
  Hilf : integer;

begin
  hilf      := XRichtung ;
  XRichtung := andereKugel.XRichtung  ;
  andereKugel.XRichtung  := hilf;

  hilf      := YRichtung;
  YRichtung := andereKugel.YRichtung ;
  andereKugel.YRichtung  := hilf;
end;


procedure TKugel.Bewegen;
(* -------------------------------------------------------------------- *)
begin
    Loeschen;
    PosVersetzen;
    BandePruefen;
    Zeigen;
    Zeit.Setpause(4);
end;

END. 
